@@ -1,12 +1,12 @@
 /*--------------------------------------------------------------------
- *	$Id: gmt2rgb.c,v 1.57 2009/09/09 23:27:01 guru Exp $
+ *	$Id: gmt2rgb.c,v 1.65 2011/03/03 21:02:50 guru Exp $
  *
- *	Copyright (c) 1991-2009 by P. Wessel and W. H. F. Smith
+ *	Copyright (c) 1991-2011 by P. Wessel and W. H. F. Smith
  *	See LICENSE.TXT file for copying and redistribution conditions.
  *
  *	This program is free software; you can redistribute it and/or modify
  *	it under the terms of the GNU General Public License as published by
- *	the Free Software Foundation; version 2 of the License.
+ *	the Free Software Foundation; version 2 or any later version.
  *
  *	This program is distributed in the hope that it will be useful,
  *	but WITHOUT ANY WARRANTY; without even the implied warranty of
@@ -31,26 +31,26 @@
 
 struct GMT2RGB_CTRL {
 	struct C {	/* -C<cptfile> */
-		BOOLEAN active;
+		GMT_LONG active;
 		char *file;
 	} C;
 	struct F {	/* -F */
-		BOOLEAN active;
+		GMT_LONG active;
 	} F;
 	struct G {	/* -G<nametemplate> */
-		BOOLEAN active;
+		GMT_LONG active;
 		char *name;
 	} G;
 	struct I {	/* -Idx[/dy] */
-		BOOLEAN active;
+		GMT_LONG active;
 		double xinc, yinc;
 	} I;
 	struct L {	/* -L<layer> */
-		BOOLEAN active;
+		GMT_LONG active;
 		char layer;
 	} L;
 	struct W {	/* -W<width/height>[/<n_bytes>] */
-		BOOLEAN active;
+		GMT_LONG active;
 		GMT_LONG nx, ny;	/* Dimension of image */
 		GMT_LONG size;	/* Number of bytes per pixels */
 	} W;
@@ -60,7 +60,7 @@ int main (int argc, char **argv)
 {
 	GMT_LONG i, error = 0, index, entry, one_or_zero, pos, nm, k, k3;
 	int irgb[3];
-	BOOLEAN guess = FALSE;
+	GMT_LONG guess = FALSE;
 	float *z;
 	double w, e, s, n;
 	struct GRD_HEADER grd;
@@ -72,11 +72,11 @@ int main (int argc, char **argv)
 	
 	void guess_width (char *file, GMT_LONG byte_per_pixel, GMT_LONG *raw_nx, GMT_LONG *raw_ny);
 	unsigned char *loadraw (char *file, struct imageinfo *header, GMT_LONG byte_per_pixel, GMT_LONG nx, GMT_LONG ny);
-	void *New_Gmt2rgb_Ctrl (), Free_Gmt2rgb_Ctrl (struct GMT2RGB_CTRL *C);
+	void *New_gmt2rgb_Ctrl (), Free_gmt2rgb_Ctrl (struct GMT2RGB_CTRL *C);
 
-	argc = GMT_begin (argc, argv);
+	argc = (int)GMT_begin (argc, argv);
 
-	Ctrl = (struct GMT2RGB_CTRL *)New_Gmt2rgb_Ctrl ();	/* Allocate and initialize a new control structure */
+	Ctrl = (struct GMT2RGB_CTRL *)New_gmt2rgb_Ctrl ();	/* Allocate and initialize a new control structure */
 
 	/* Check and interpret the command line arguments */
 
@@ -101,7 +101,6 @@ int main (int argc, char **argv)
 					Ctrl->F.active = TRUE;
 					break;
 				case 'G':
-					GMT_free ((void *)Ctrl->G.name);
 					Ctrl->G.name = strdup (&argv[i][2]);
 					break;
 				case 'I':
@@ -292,16 +291,16 @@ int main (int argc, char **argv)
 		}
 		if (w == e && s == n) {	/* R not given, provide default */
 			w = s = 0.0;
-			e = header.width - one_or_zero;
-			n = header.height - one_or_zero;
+			e = (double)(header.width - one_or_zero);
+			n = (double)(header.height - one_or_zero);
 			if (gmtdefs.verbose) fprintf (stderr, "%s: Assign default -R0/%g/0/%g\n", GMT_program, e, n);
 		}
 
-		grd.nx = irint ((e-w)/Ctrl->I.xinc) + one_or_zero;
-		grd.ny = irint ((n-s)/Ctrl->I.yinc) + one_or_zero;
+		grd.nx = (int)(irint ((e-w)/Ctrl->I.xinc) + one_or_zero);
+		grd.ny = (int)(irint ((n-s)/Ctrl->I.yinc) + one_or_zero);
 		if (Ctrl->W.active && !Ctrl->I.active) {		/* This isn't correct because it doesn't deal with -F */
-			grd.nx = Ctrl->W.nx;
-			grd.ny = Ctrl->W.ny;
+			grd.nx = (int)Ctrl->W.nx;
+			grd.ny = (int)Ctrl->W.ny;
 			Ctrl->I.xinc = (e-w)/(Ctrl->W.nx - one_or_zero);
 			Ctrl->I.yinc = (n-s)/(Ctrl->W.ny - one_or_zero);
 		}
@@ -344,7 +343,7 @@ int main (int argc, char **argv)
 	}
 	GMT_free ((void *)z);
 
-	Free_Gmt2rgb_Ctrl (Ctrl);	/* Deallocate control structure */
+	Free_gmt2rgb_Ctrl (Ctrl);	/* Deallocate control structure */
 
 	GMT_end (argc, argv);
 
@@ -367,10 +366,10 @@ unsigned char *loadraw (char *file, struct imageinfo *header, GMT_LONG byte_per_
 	/* Lets pretend that the raw file is a sunraster file. This way the gmt2rgb code
 	   can be used with very little changes */
 	header->depth = 24;
-	header->width = nx;
-	header->height = ny;
+	header->width = (int)nx;
+	header->height = (int)ny;
 	nm = ((size_t)nx) * ((size_t)ny) * ((size_t)byte_per_pixel);
-	header->length = nm;
+	header->length = (int)nm;
 
 	buffer = (unsigned char *) GMT_memory (VNULL, (size_t)nm, sizeof (unsigned char), GMT_program);
 	if (GMT_fread ((void *)buffer, (size_t)1, (size_t)nm, fp) != (size_t)nm) {
@@ -495,10 +494,10 @@ void guess_width (char *file, GMT_LONG byte_per_pixel, GMT_LONG *raw_nx, GMT_LON
 	GMT_free ((void *)img_pow);
 }
 
-void *New_Gmt2rgb_Ctrl () {	/* Allocate and initialize a new control structure */
+void *New_gmt2rgb_Ctrl () {	/* Allocate and initialize a new control structure */
 	struct GMT2RGB_CTRL *C;
 	
-	C = (struct GMT2RGB_CTRL *) GMT_memory (VNULL, (size_t)1, sizeof (struct GMT2RGB_CTRL), "New_Gmt2rgb_Ctrl");
+	C = (struct GMT2RGB_CTRL *) GMT_memory (VNULL, (size_t)1, sizeof (struct GMT2RGB_CTRL), "New_gmt2rgb_Ctrl");
 	
 	/* Initialize values whose defaults are not 0/FALSE/NULL */
 	
@@ -508,7 +507,7 @@ void *New_Gmt2rgb_Ctrl () {	/* Allocate and initialize a new control structure *
 	return ((void *)C);
 }
 
-void Free_Gmt2rgb_Ctrl (struct GMT2RGB_CTRL *C) {	/* Deallocate control structure */
+void Free_gmt2rgb_Ctrl (struct GMT2RGB_CTRL *C) {	/* Deallocate control structure */
 	if (C->C.file) free ((void *)C->C.file);	
 	if (C->G.name) free ((void *)C->G.name);	
 	GMT_free ((void *)C);	
