@@ -1,12 +1,12 @@
 /*--------------------------------------------------------------------
- *	$Id: grd2cpt.c,v 1.55 2009/05/13 21:06:42 guru Exp $
+ *	$Id: grd2cpt.c,v 1.64 2011/03/03 21:02:51 guru Exp $
  *
- *	Copyright (c) 1991-2009 by P. Wessel and W. H. F. Smith
- *	See COPYING file for copying and redistribution conditions.
+ *	Copyright (c) 1991-2011 by P. Wessel and W. H. F. Smith
+ *	See LICENSE.TXT file for copying and redistribution conditions.
  *
  *	This program is free software; you can redistribute it and/or modify
  *	it under the terms of the GNU General Public License as published by
- *	the Free Software Foundation; version 2 of the License.
+ *	the Free Software Foundation; version 2 or any later version.
  *
  *	This program is distributed in the hope that it will be useful,
  *	but WITHOUT ANY WARRANTY; without even the implied warranty of
@@ -42,51 +42,51 @@
 
 struct GRD2CPT_CTRL {
 	struct C {	/* -C<cpt> */
-		BOOLEAN active;
+		GMT_LONG active;
 		char *file;
 	} C;
 	struct D {	/* -D */
-		BOOLEAN active;
+		GMT_LONG active;
 	} D;
 	struct E {	/* -E<nlevels> */
-		BOOLEAN active;
+		GMT_LONG active;
 		int levels;
 	} E;
 	struct I {	/* -I */
-		BOOLEAN active;
+		GMT_LONG active;
 	} I;
 	struct L {	/* -L<min_limit>/<max_limit> */
-		BOOLEAN active;
+		GMT_LONG active;
 		double min, max;
 	} L;
 	struct M {	/* -M */
-		BOOLEAN active;
+		GMT_LONG active;
 	} M;
 	struct N {	/* -N */
-		BOOLEAN active;
+		GMT_LONG active;
 	} N;
 	struct Q {	/* -Q[i|o */
-		BOOLEAN active;
+		GMT_LONG active;
 		GMT_LONG mode;
 	} Q;
 	struct S {	/* -S<z_start>/<z_stop>/<z_inc> */
-		BOOLEAN active;
-		BOOLEAN cpt;
+		GMT_LONG active;
+		GMT_LONG cpt;
 		double low, high, inc;
 		char *file;
 	} S;
 	struct T {	/* -T<kind> */
-		BOOLEAN active;
+		GMT_LONG active;
 		GMT_LONG kind; /* -1 symmetric +-zmin, +1 +-zmax, -2 = +-Minx(|zmin|,|zmax|), +2 = +-Max(|zmin|,|zmax|), 0 = min to max [Default] */
 	} T;
 	struct Z {	/* -Z */
-		BOOLEAN active;
+		GMT_LONG active;
 	} Z;
 };
 
 int main (int argc, char **argv)
 {
-	BOOLEAN error = FALSE, global = FALSE;
+	GMT_LONG error = FALSE, global = FALSE;
 
 #define mgrd 1000
 
@@ -107,11 +107,11 @@ int main (int argc, char **argv)
 
 	FILE	*fpc = NULL;
 
-	void *New_Grd2cpt_Ctrl (), Free_Grd2cpt_Ctrl (struct GRD2CPT_CTRL *C);
+	void *New_grd2cpt_Ctrl (), Free_grd2cpt_Ctrl (struct GRD2CPT_CTRL *C);
 
-	argc = GMT_begin (argc, argv);
+	argc = (int)GMT_begin (argc, argv);
 
-	Ctrl = (struct GRD2CPT_CTRL *)New_Grd2cpt_Ctrl ();	/* Allocate and initialize a new control structure */
+	Ctrl = (struct GRD2CPT_CTRL *)New_grd2cpt_Ctrl ();	/* Allocate and initialize a new control structure */
 
 	w = e = s = n = 0.0;
 
@@ -394,7 +394,7 @@ int main (int argc, char **argv)
 	if (Ctrl->S.active) {
 		/* Use predefined levels and interval */
 		Ctrl->E.levels = (grd.z_min < Ctrl->S.low) ? 1 : 0;
-		Ctrl->E.levels += (GMT_LONG)floor((Ctrl->S.high - Ctrl->S.low)/Ctrl->S.inc) + 1;
+		Ctrl->E.levels += (int)floor((Ctrl->S.high - Ctrl->S.low)/Ctrl->S.inc) + 1;
 		if (grd.z_max > Ctrl->S.high) Ctrl->E.levels++;
 		cdf_cpt = (struct CDF_CPT *)GMT_memory (VNULL, (size_t)Ctrl->E.levels, sizeof(struct CDF_CPT), GMT_program);
 		if (grd.z_min < Ctrl->S.low) {
@@ -490,9 +490,9 @@ int main (int argc, char **argv)
 
 	/* Write to GMT_stdout.  */
 
-	fprintf (GMT_stdout, "#\tcpt file created by: %s", GMT_program);
-	for (i = 1; i < argc; i++) fprintf (GMT_stdout, " %s", argv[i]);
-	fprintf (GMT_stdout, "\n");
+	sprintf (format, "#\tcpt file created by: %s", GMT_program);	GMT_fputs (format, GMT_stdout);
+	for (i = 1; i < argc; i++) {sprintf (format, " %s", argv[i]);	GMT_fputs (format, GMT_stdout);}
+	GMT_fputs ("\n", GMT_stdout);
 
 
 	z = (double *) GMT_memory (VNULL, (size_t)Ctrl->E.levels, sizeof (double), GMT_program);
@@ -505,23 +505,23 @@ int main (int argc, char **argv)
 	GMT_free ((void *)zdata);
 	GMT_free ((void *)z);
 
-	Free_Grd2cpt_Ctrl (Ctrl);	/* Deallocate control structure */
+	Free_grd2cpt_Ctrl (Ctrl);	/* Deallocate control structure */
 
 	GMT_end (argc, argv);
 
 	exit (EXIT_SUCCESS);
 }
 
-void *New_Grd2cpt_Ctrl () {	/* Allocate and initialize a new control structure */
+void *New_grd2cpt_Ctrl () {	/* Allocate and initialize a new control structure */
 	struct GRD2CPT_CTRL *C;
 
-	C = (struct GRD2CPT_CTRL *) GMT_memory (VNULL, (size_t)1, sizeof (struct GRD2CPT_CTRL), "New_Grd2cpt_Ctrl");
+	C = (struct GRD2CPT_CTRL *) GMT_memory (VNULL, (size_t)1, sizeof (struct GRD2CPT_CTRL), "New_grd2cpt_Ctrl");
 
 	/* Initialize values whose defaults are not 0/FALSE/NULL */
 	return ((void *)C);
 }
 
-void Free_Grd2cpt_Ctrl (struct GRD2CPT_CTRL *C) {	/* Deallocate control structure */
+void Free_grd2cpt_Ctrl (struct GRD2CPT_CTRL *C) {	/* Deallocate control structure */
 	if (C->C.file) free ((void *)C->C.file);
 	GMT_free ((void *)C);
 }
