@@ -1,12 +1,12 @@
 /*--------------------------------------------------------------------
- *	$Id: grdview.c,v 1.106 2009/06/12 02:06:05 remko Exp $
+ *	$Id: grdview.c,v 1.118 2011/03/03 21:02:51 guru Exp $
  *
- *	Copyright (c) 1991-2009 by P. Wessel and W. H. F. Smith
- *	See COPYING file for copying and redistribution conditions.
+ *	Copyright (c) 1991-2011 by P. Wessel and W. H. F. Smith
+ *	See LICENSE.TXT file for copying and redistribution conditions.
  *
  *	This program is free software; you can redistribute it and/or modify
  *	it under the terms of the GNU General Public License as published by
- *	the Free Software Foundation; version 2 of the License.
+ *	the Free Software Foundation; version 2 or any later version.
  *
  *	This program is distributed in the hope that it will be useful,
  *	but WITHOUT ANY WARRANTY; without even the implied warranty of
@@ -48,60 +48,60 @@
 
 struct GRDVIEW_CTRL {
 	struct C {	/* -C<cpt> */
-		BOOLEAN active;
+		GMT_LONG active;
 		char *file;
 	} C;
 	struct E {	/* -E<azimuth/elevation> */
-		BOOLEAN active;
+		GMT_LONG active;
 		double azimuth, elevation;
 	} E;
 	struct G {	/* -G<drapefile> */
-		BOOLEAN active;
-		BOOLEAN image;
+		GMT_LONG active;
+		GMT_LONG image;
 		char *file[3];
 	} G;
 	struct I {	/* -G<intensfile> */
-		BOOLEAN active;
+		GMT_LONG active;
 		char *file;
 	} I;
 	struct L {	/* -L<flag> */
-		BOOLEAN active;
-		BOOLEAN interpolant;
+		GMT_LONG active;
+		GMT_LONG interpolant;
 		char mode[4];
 		double threshold;
 	} L;
 	struct N {	/* -N<level>[/<color>] */
-		BOOLEAN active;
-		BOOLEAN facade;
+		GMT_LONG active;
+		GMT_LONG facade;
 		int rgb[3];
 		double level;
 	} N;
 	struct Q {	/* -Q<type>[g] */
-		BOOLEAN active, special;
-		BOOLEAN outline;
-		BOOLEAN mask;
-		BOOLEAN monochrome;
+		GMT_LONG active, special;
+		GMT_LONG outline;
+		GMT_LONG mask;
+		GMT_LONG monochrome;
 		GMT_LONG mode;	/* GRDVIEW_MESH, GRDVIEW_SURF, GRDVIEW_IMAGE */
 		GMT_LONG dpi;
 		struct GMT_FILL fill;
 	} Q;
 	struct S {	/* -S<smooth> */
-		BOOLEAN active;
+		GMT_LONG active;
 		GMT_LONG value;
 	} S;
 	struct T {	/* -T[s][o[<pen>] */
-		BOOLEAN active;
-		BOOLEAN skip;
-		BOOLEAN outline;
+		GMT_LONG active;
+		GMT_LONG skip;
+		GMT_LONG outline;
 		struct GMT_PEN pen;
 	} T;
 	struct W {	/* -W[+]<type><pen> */
-		BOOLEAN active;
-		BOOLEAN contour;
+		GMT_LONG active;
+		GMT_LONG contour;
 		struct GMT_PEN pen[3];
 	} W;
 	struct Z {	/* -Z<z_level> */
-		BOOLEAN active;
+		GMT_LONG active;
 		double level;
 	} Z;
 };
@@ -123,8 +123,8 @@ struct GRDVIEW_POINT {
 
 int main (int argc, char **argv)
 {
-	BOOLEAN get_contours, bad, set_z = FALSE, error = FALSE, pen_not_set;
-	BOOLEAN first, begin, saddle, subset = FALSE, no_nans, drape_resample = FALSE;
+	GMT_LONG get_contours, bad, set_z = FALSE, error = FALSE, pen_not_set;
+	GMT_LONG first, begin, saddle, subset = FALSE, no_nans, drape_resample = FALSE;
 
 	char *topofile;
 	char *c_method[2] = {"colorimage", "colortiles",};
@@ -132,7 +132,7 @@ int main (int argc, char **argv)
 	GMT_LONG j, n_edges, max, i_bin, j_bin, i_bin_old, j_bin_old, nx_f, ny_f, nx, ny;
 	GMT_LONG sw, se, nw, ne, id, n4, nk, c, i_start, i_stop, j_start, j_stop, i_inc, j_inc, ii, jj;
 	GMT_LONG bin, i, ij, k, k1, n, nm, nm2, nm_use, mx, my, n_drape = 0, n_out, bin_inc[4], ij_inc[4];
-	GMT_LONG PS_colormask_off = 0, PS_colormask, n_commas, q_set = 0, two, side, way, *edge;
+	GMT_LONG PS_colormask_off = 0, PS_colormask, n_commas, q_set = 0, two, way, *edge;
 
 	int rgb[3];
 	
@@ -155,20 +155,20 @@ int main (int argc, char **argv)
 	void copy_points_bw (double x[], double y[], double z[], double v[], double xcont[], double ycont[], double zcont[], double vcont[], GMT_LONG cont, GMT_LONG *n);
 	double get_z_ave (double v[], double next_up, GMT_LONG n);
 	void add_node (double x[], double y[], double z[], double v[], GMT_LONG *k, GMT_LONG node, double X_vert[], double Y_vert[], float topo[], float zgrd[], GMT_LONG ij, GMT_LONG bin);
-	void paint_it (double x[], double y[], GMT_LONG n, double z, BOOLEAN intens, BOOLEAN monochrome, double intensity, BOOLEAN outline);
+	void paint_it (double x[], double y[], GMT_LONG n, double z, GMT_LONG intens, GMT_LONG monochrome, double intensity, GMT_LONG outline);
 	double get_intensity (float *intensity, GMT_LONG k, GMT_LONG nx);
 	struct GRDVIEW_CONT *get_cont_struct (GMT_LONG bin, struct GRDVIEW_BIN *binij, double value);
 	struct GRDVIEW_POINT *get_point (double x, double y);
-	void grdview_init_setup (struct GRD_HEADER *header, float *topo, GMT_LONG two, BOOLEAN draw_plane, double plane_level);
+	void grdview_init_setup (struct GRD_HEADER *header, float *topo, GMT_LONG two, GMT_LONG draw_plane, double plane_level);
 	GMT_LONG pixel_inside (GMT_LONG ip, GMT_LONG jp, GMT_LONG *ix, GMT_LONG *iy, GMT_LONG bin, GMT_LONG bin_inc[]);
 	GMT_LONG quick_idist(GMT_LONG x1, GMT_LONG y1, GMT_LONG x2, GMT_LONG y2);
 	GMT_LONG get_side (double x, double y, double x_left, double y_bottom, double xinc, double yinc, double dx2, double dy2);
-	BOOLEAN GMT_rgb_is_nan_rgb (int rgb[]);
-	void *New_Grdview_Ctrl (), Free_Grdview_Ctrl (struct GRDVIEW_CTRL *C);
+	GMT_LONG GMT_rgb_is_nan_rgb (int rgb[]);
+	void *New_grdview_Ctrl (), Free_grdview_Ctrl (struct GRDVIEW_CTRL *C);
 
-	argc = GMT_begin (argc, argv);
+	argc = (int)GMT_begin (argc, argv);
 
-	Ctrl = (struct GRDVIEW_CTRL *)New_Grdview_Ctrl ();	/* Allocate and initialize a new control structure */
+	Ctrl = (struct GRDVIEW_CTRL *)New_grdview_Ctrl ();	/* Allocate and initialize a new control structure */
 	
 	topofile = CNULL;
 	GMT_3D_mode = 1;	/* Only do background axis first; do foreground at end */
@@ -314,33 +314,24 @@ int main (int argc, char **argv)
 				case 'W':	/* Contour, mesh, or facade pens */
 					Ctrl->W.active = TRUE;
 					j = (argv[i][2] == 'm' || argv[i][2] == 'c' || argv[i][2] == 'f') ? 3 : 2;
-					if (j == 2) {   /* Set all */
-						if (GMT_getpen (&argv[i][2], &Ctrl->W.pen[0])) {
-							GMT_pen_syntax ('W', " ");
-							error++;
-						}
-						else
-							Ctrl->W.pen[2] = Ctrl->W.pen[1] = Ctrl->W.pen[0];
-						Ctrl->W.contour = TRUE;
-					}
-					else {	/* Here , j = 3.  BUT: First check that the m or c is not part of a color name instead */
+					id = 0;
+					if (j == 3) {	/* First check that the m or c is not part of a color name instead */
 						char txt_a[GMT_LONG_TEXT];
 						n = j+1;
-						while (!(argv[i][n] == ',' || argv[i][n] == '/' || argv[i][n] == '\0')) n++;
+						while (argv[i][n] && argv[i][n] != ',' && argv[i][n] != '/') n++;	/* Wind until end or , or / */
 						strncpy (txt_a, &argv[i][2], (size_t)(n-2));	txt_a[n-2] = '\0';
-						if (GMT_colorname2index (txt_a) >= 0) j = 2;	/* Found a colorname; reset j to 2 */
-						id = (argv[i][2] == 'f') ? 2 : ((argv[i][2] == 'm') ? 1 : 0);
-						if (GMT_getpen (&argv[i][j], &Ctrl->W.pen[id])) {
-							GMT_pen_syntax ('W', " ");
-							error++;
-						}
-						if (j == 2) {	/* We discovered it wasnt -Wc or -Wm after all so copy pen */
-							Ctrl->W.pen[2] = Ctrl->W.pen[1] = Ctrl->W.pen[0];
-							Ctrl->W.contour = TRUE;
-						}
-						else if (id == 0)
-							Ctrl->W.contour = TRUE;
+						if (GMT_colorname2index (txt_a) >= 0)	/* Found a colorname; reset j to 2 */
+							j = 2;
+						else
+							id = (argv[i][2] == 'f') ? 2 : ((argv[i][2] == 'm') ? 1 : 0);
 					}
+					if (GMT_getpen (&argv[i][j], &Ctrl->W.pen[id])) {
+						GMT_pen_syntax ('W', " ");
+						error++;
+					}
+					if (j == 2)	/* Copy pen when using just -W */
+						Ctrl->W.pen[2] = Ctrl->W.pen[1] = Ctrl->W.pen[0];
+					if (id == 0) Ctrl->W.contour = TRUE;	/* Switch contouring ON for -Wc or -W */
 					break;
 				case 'Z':
 					if (argv[i][2]) {
@@ -506,6 +497,11 @@ int main (int argc, char **argv)
 	GMT_err_fail (GMT_read_grd_info (topofile, &t_head), topofile);
 	if (Ctrl->I.active) GMT_err_fail (GMT_read_grd_info (Ctrl->I.file, &i_head), Ctrl->I.file);
 
+	if (Ctrl->I.active && (t_head.nx != i_head.nx || t_head.ny != i_head.ny)) {
+		fprintf (stderr, "%s: GMT ERROR: topo and illumination files have not the same size!\n", GMT_program);
+		exit (EXIT_FAILURE);
+	}
+
 	if (Ctrl->G.active) {
 		for (i = 0; i < n_drape; i++) GMT_err_fail (GMT_read_grd_info (Ctrl->G.file[i], &d_head[i]), Ctrl->G.file[i]);
 		two = 2; 
@@ -645,33 +641,26 @@ int main (int argc, char **argv)
 				if (zgrd[i] == 0.0) zgrd[i] += (float)small;
 			}
 
-			side = 0;
 			begin = TRUE;
-			while (side <= GMT_LAST_CONTOUR_SIDE) {
-				while ((n = GMT_contours (zgrd, &header, Ctrl->S.value, gmtdefs.interpolant, 0, &side, edge, begin, &x, &y)) > 0) {
-
-					begin = FALSE;
-
-					i_bin_old = j_bin_old = -1;
-					for (i = 1; i < n; i++) {
-						i_bin = (GMT_LONG)floor (((0.5 * (x[i-1] + x[i]) - header.x_min) / header.x_inc) - header.xy_off);
-						j_bin = (GMT_LONG)floor (((header.y_max - 0.5 * (y[i-1] + y[i])) / header.y_inc) - header.xy_off) + 1;
-						if (i_bin != i_bin_old || j_bin != j_bin_old) {	/* Entering new bin */
-							bin = j_bin * header.nx + i_bin;
-							this_cont = get_cont_struct (bin, binij, cval);
-							this_cont->value = cval;
-							this_cont->first_point = get_point (x[i-1], y[i-1]);
-							this_point = this_cont->first_point;
-							i_bin_old = i_bin;
-							j_bin_old = j_bin;
-						}
-						this_point->next_point = get_point (x[i], y[i]);
-						this_point = this_point->next_point;
+			while ((n = GMT_contours (zgrd, &header, Ctrl->S.value, gmtdefs.interpolant, 0, edge, &begin, &x, &y)) > 0) {
+				i_bin_old = j_bin_old = -1;
+				for (i = 1; i < n; i++) {
+					i_bin = (GMT_LONG)floor (((0.5 * (x[i-1] + x[i]) - header.x_min) / header.x_inc) - header.xy_off);
+					j_bin = (GMT_LONG)floor (((header.y_max - 0.5 * (y[i-1] + y[i])) / header.y_inc) - header.xy_off) + 1;
+					if (i_bin != i_bin_old || j_bin != j_bin_old) {	/* Entering new bin */
+						bin = j_bin * header.nx + i_bin;
+						this_cont = get_cont_struct (bin, binij, cval);
+						this_cont->value = cval;
+						this_cont->first_point = get_point (x[i-1], y[i-1]);
+						this_point = this_cont->first_point;
+						i_bin_old = i_bin;
+						j_bin_old = j_bin;
 					}
-					GMT_free ((void *)x);
-					GMT_free ((void *)y);
+					this_point->next_point = get_point (x[i], y[i]);
+					this_point = this_point->next_point;
 				}
-				begin = FALSE;
+				GMT_free ((void *)x);
+				GMT_free ((void *)y);
 			}
 		}
 
@@ -862,7 +851,7 @@ int main (int argc, char **argv)
 	if (Ctrl->Q.mode == GRDVIEW_IMAGE) {	/* compute image */
 		GMT_LONG nx_i, ny_i, kk, ip, jp, min_i, max_i, min_j, max_j, dist, node, nm_i, nm_drape, layers, last_i, last_j, p;
 		GMT_LONG *top_jp = VNULL, *bottom_jp = VNULL, *ix, *iy;
-		BOOLEAN done;
+		GMT_LONG done;
 		double xp, yp, sum_w, w, sum_i, x_width, y_width, value;
 		double sum_r, sum_g, sum_b, intval = 0.0, y_drape, *x_drape;
 		float *int_drape = VNULL;
@@ -1107,14 +1096,14 @@ int main (int argc, char **argv)
 		if (Ctrl->Q.monochrome) Ctrl->Q.fill.rgb[0] = Ctrl->Q.fill.rgb[1] = Ctrl->Q.fill.rgb[2] = GMT_YIQ (Ctrl->Q.fill.rgb);	/* Do GMT_YIQ transformation */
 		for (j = j_start; j != j_stop; j += j_inc) {
 			y_bottom = yval[j];
-			y_top = y_bottom + abs (j_inc) * header.y_inc;
+			y_top = y_bottom + GMT_abs (j_inc) * header.y_inc;
 			for (i = i_start; i != i_stop; i += i_inc) {
 				bin = j * header.nx + i;
 				ij = (two) ? (j + 2) * mx + i + 2 : bin;
 				for (k = bad = 0; !bad && k < 4; k++) bad += GMT_is_fnan (topo[ij+ij_inc[k]]);
 				if (bad) continue;
 				x_left = xval[i];
-				x_right = x_left + abs (i_inc) * header.x_inc;
+				x_right = x_left + GMT_abs (i_inc) * header.x_inc;
 				GMT_geoz_to_xy (x_left, y_bottom, (double)(topo[ij+ij_inc[0]]), &xx[0], &yy[0]);
 				GMT_geoz_to_xy (x_right, y_bottom, (double)(topo[ij+ij_inc[1]]), &xx[1], &yy[1]);
 				GMT_geoz_to_xy (x_right, y_top, (double)(topo[ij+ij_inc[2]]), &xx[2], &yy[2]);
@@ -1438,14 +1427,15 @@ int main (int argc, char **argv)
 						ps_patch (xmesh, ymesh, (GMT_LONG)4, GMT_no_rgb, TRUE);
 					}
 				}
-				else {	/* No Contours, paint tile (any of the corner values will give correct color */
+				else {	/* No Contours */
 
-					if (GMT_continuous) {
+					if (GMT_continuous) {	/* Take the color corresponding to the average value of the four corners */
 						for (n = 0, z_ave = 0.0; n < 4; n++) z_ave += zgrd[bin+bin_inc[n]];
 						z_ave *= 0.25;
 					}
-					else
+					else	/* Take the value of any corner */
 						z_ave = zgrd[bin];
+						
 					/* Now paint the polygon piece */
 
 					for (k = 0; k < 4; k++) GMT_geoz_to_xy (X_vert[k], Y_vert[k], (double)(topo[ij+ij_inc[k]]), &xmesh[k], &ymesh[k]);
@@ -1547,7 +1537,7 @@ int main (int argc, char **argv)
 
 	if (gmtdefs.verbose) fprintf (stderr, "%s: Done!\n", GMT_program);
 
-	Free_Grdview_Ctrl (Ctrl);	/* Deallocate control structure */
+	Free_grdview_Ctrl (Ctrl);	/* Deallocate control structure */
 
 	GMT_end (argc, argv);
 
@@ -1582,7 +1572,7 @@ struct GRDVIEW_POINT *get_point (double x, double y)
 	return (point);
 }
 
-void grdview_init_setup (struct GRD_HEADER *header, float *topo, GMT_LONG two, BOOLEAN draw_plane, double plane_level)
+void grdview_init_setup (struct GRD_HEADER *header, float *topo, GMT_LONG two, GMT_LONG draw_plane, double plane_level)
 {
 	GMT_LONG i, j, ij;
 	double xtmp, ytmp, tmp, delx, dely;
@@ -1636,8 +1626,8 @@ GMT_LONG pixel_inside (GMT_LONG ip, GMT_LONG jp, GMT_LONG *ix, GMT_LONG *iy, GMT
 	double x[6], y[6];
 
 	for (i = 0; i < 4; i++) {
-		x[i] = ix[bin+bin_inc[i]];
-		y[i] = iy[bin+bin_inc[i]];
+		x[i] = (double)ix[bin+bin_inc[i]];
+		y[i] = (double)iy[bin+bin_inc[i]];
 	}
 	x[4] = x[0];	y[4] = y[0];
 	what = GMT_non_zero_winding ((double)ip, (double)jp, x, y, (GMT_LONG)5);
@@ -1705,7 +1695,7 @@ void add_node (double x[], double y[], double z[], double v[], GMT_LONG *k, GMT_
 	(*k)++;
 }
 
-void paint_it (double x[], double y[], GMT_LONG n, double z, BOOLEAN intens, BOOLEAN monochrome, double intensity, BOOLEAN outline) {
+void paint_it (double x[], double y[], GMT_LONG n, double z, GMT_LONG intens, GMT_LONG monochrome, double intensity, GMT_LONG outline) {
 	GMT_LONG index;
 	int rgb[3];
 	struct GMT_FILL *f;
@@ -1727,15 +1717,15 @@ void paint_it (double x[], double y[], GMT_LONG n, double z, BOOLEAN intens, BOO
 	}
 }
 
-BOOLEAN GMT_rgb_is_nan_rgb (int rgb[])
+GMT_LONG GMT_rgb_is_nan_rgb (int rgb[])
 {
 	return (rgb[0] == GMT_bfn[GMT_NAN].rgb[0] && rgb[1] == GMT_bfn[GMT_NAN].rgb[1] && rgb[2] == GMT_bfn[GMT_NAN].rgb[2]);
 }
 
-void *New_Grdview_Ctrl () {	/* Allocate and initialize a new control structure */
+void *New_grdview_Ctrl () {	/* Allocate and initialize a new control structure */
 	struct GRDVIEW_CTRL *C;
 	
-	C = (struct GRDVIEW_CTRL *) GMT_memory (VNULL, (size_t)1, sizeof (struct GRDVIEW_CTRL), "New_Grdview_Ctrl");
+	C = (struct GRDVIEW_CTRL *) GMT_memory (VNULL, (size_t)1, sizeof (struct GRDVIEW_CTRL), "New_grdview_Ctrl");
 	
 	/* Initialize values whose defaults are not 0/FALSE/NULL */
 	C->E.azimuth = 180.0;
@@ -1751,7 +1741,7 @@ void *New_Grdview_Ctrl () {	/* Allocate and initialize a new control structure *
 	return ((void *)C);
 }
 
-void Free_Grdview_Ctrl (struct GRDVIEW_CTRL *C) {	/* Deallocate control structure */
+void Free_grdview_Ctrl (struct GRDVIEW_CTRL *C) {	/* Deallocate control structure */
 	GMT_LONG i;
 	if (C->C.file) free ((void *)C->C.file);	
 	for (i = 0; i < 3; i++) if (C->G.file[i]) free ((void *)C->G.file[i]);	
