@@ -1,12 +1,12 @@
 /*--------------------------------------------------------------------
- *	$Id: pshistogram.c,v 1.69 2009/09/09 23:27:03 guru Exp $
+ *	$Id: pshistogram.c,v 1.79 2011/03/03 21:02:51 guru Exp $
  *
- *	Copyright (c) 1991-2009 by P. Wessel and W. H. F. Smith
+ *	Copyright (c) 1991-2011 by P. Wessel and W. H. F. Smith
  *	See LICENSE.TXT file for copying and redistribution conditions.
  *
  *	This program is free software; you can redistribute it and/or modify
  *	it under the terms of the GNU General Public License as published by
- *	the Free Software Foundation; version 2 of the License.
+ *	the Free Software Foundation; version 2 or any later version.
  *
  *	This program is distributed in the hope that it will be useful,
  *	but WITHOUT ANY WARRANTY; without even the implied warranty of
@@ -37,47 +37,47 @@
 
 struct PSHISTOGRAM_CTRL {
 	struct A {	/* -A */
-		BOOLEAN active;
+		GMT_LONG active;
 	} A;
 	struct C {	/* -C<cpt> */
-		BOOLEAN active;
+		GMT_LONG active;
 		char *file;
 	} C;
 	struct E {	/* -Eazimuth/elevation */
-		BOOLEAN active;
+		GMT_LONG active;
 		double azimuth, elevation;
 	} E;
 	struct F {	/* -F */
-		BOOLEAN active;
+		GMT_LONG active;
 	} F;
 	struct G {	/* -Gfill */
-		BOOLEAN active;
+		GMT_LONG active;
 		struct GMT_FILL fill;
 	} G;
 	struct I {	/* -I[o] */
-		BOOLEAN active;
+		GMT_LONG active;
 		GMT_LONG mode;
 	} I;
 	struct L {	/* -L<pen> */
-		BOOLEAN active;
+		GMT_LONG active;
 		struct GMT_PEN pen;
 	} L;
 	struct Q {	/* -Q */
-		BOOLEAN active;
+		GMT_LONG active;
 	} Q;
 	struct S {	/* -S */
-		BOOLEAN active;
+		GMT_LONG active;
 	} S;
 	struct T {	/* -T<col> */
-		BOOLEAN active;
+		GMT_LONG active;
 		GMT_LONG col;
 	} T;
 	struct W {	/* -W<width> */
-		BOOLEAN active;
+		GMT_LONG active;
 		double inc;
 	} W;
 	struct Z {	/* -Z<type> */
-		BOOLEAN active;
+		GMT_LONG active;
 		GMT_LONG mode;
 	} Z;
 };
@@ -102,12 +102,12 @@ struct PSHISTOGRAM_INFO {	/* Control structure for pshistogram */
 
 int main (int argc, char **argv)
 {
-	BOOLEAN error = FALSE, automatic = FALSE;
+	GMT_LONG error = FALSE, automatic = FALSE;
 
 	char buffer[BUFSIZ], format[BUFSIZ], *not_used = NULL;
 	
 	GMT_LONG i, n_alloc = GMT_CHUNK, n;
-	GMT_LONG n_expected_fields, n_fields;
+	GMT_LONG n_expected_fields, n_fields, n_read;
 	
 	double	*data, stats[6];
 
@@ -119,13 +119,13 @@ int main (int argc, char **argv)
 	struct PSHISTOGRAM_CTRL *Ctrl;
 	
 	GMT_LONG fill_boxes (struct PSHISTOGRAM_INFO *F, double *x, GMT_LONG n);
-	GMT_LONG plot_boxes (struct PSHISTOGRAM_INFO *F, BOOLEAN stairs, BOOLEAN flip_to_y, BOOLEAN draw_outline, struct GMT_PEN *pen, struct GMT_FILL *fill, BOOLEAN cpt);
+	GMT_LONG plot_boxes (struct PSHISTOGRAM_INFO *F, GMT_LONG stairs, GMT_LONG flip_to_y, GMT_LONG draw_outline, struct GMT_PEN *pen, struct GMT_FILL *fill, GMT_LONG cpt);
 	GMT_LONG get_loc_scl (double *x, GMT_LONG n, double *stats);
-	void *New_Pshistogram_Ctrl (), Free_Pshistogram_Ctrl (struct PSHISTOGRAM_CTRL *C);
+	void *New_pshistogram_Ctrl (), Free_pshistogram_Ctrl (struct PSHISTOGRAM_CTRL *C);
 
-	argc = GMT_begin (argc, argv);
+	argc = (int)GMT_begin (argc, argv);
 
-	Ctrl = (struct PSHISTOGRAM_CTRL *)New_Pshistogram_Ctrl ();	/* Allocate and initialize a new control structure */
+	Ctrl = (struct PSHISTOGRAM_CTRL *)New_pshistogram_Ctrl ();	/* Allocate and initialize a new control structure */
 
 	memset ((void *)&F, 0, sizeof (struct PSHISTOGRAM_INFO));
 	F.hist_type = PSHISTOGRAM_COUNTS;
@@ -354,21 +354,23 @@ int main (int argc, char **argv)
 
 	data = (double *) GMT_memory (VNULL, (size_t)n_alloc , sizeof (double), GMT_program);
 
-	n = 0;
+	n = n_read = 0;
 	x_min = DBL_MAX;	x_max = -DBL_MAX;
-	n_expected_fields = (GMT_io.ncol[GMT_IN]) ? GMT_io.ncol[GMT_IN] : BUFSIZ;
+	n_expected_fields = (GMT_io.ncol[GMT_IN]) ? GMT_io.ncol[GMT_IN] : GMT_MAX_COLUMNS;
 
 	if (GMT_io.io_header[GMT_IN]) for (i = 0; i < GMT_io.n_header_recs; i++) not_used = GMT_fgets (buffer, BUFSIZ, fp_in);
 
 	while ((n_fields = GMT_input (fp_in, &n_expected_fields, &in)) >= 0 && !(GMT_io.status & GMT_IO_EOF)) {
 
+		n_read++;
+
 		if (GMT_io.status & GMT_IO_MISMATCH) {
-			fprintf (stderr, "%s: Mismatch between actual (%ld) and expected (%d) fields near line %ld\n", GMT_program, n_fields, 2, n);
-			exit (EXIT_FAILURE);
+			fprintf (stderr, "%s: Mismatch between actual (%ld) and expected (%d) fields near line %ld (skipped)\n", GMT_program, n_fields, 2, n_read);
+			continue;
 		}
 		if (Ctrl->T.col >= n_fields) {
-			fprintf (stderr, "%s: Expected at least %ld fields but only found %ld near line %ld\n", GMT_program, Ctrl->T.col+1, n_fields, n);
-			exit (EXIT_FAILURE);
+			fprintf (stderr, "%s: Expected at least %ld fields but only found %ld near line %ld (skipped)\n", GMT_program, Ctrl->T.col+1, n_fields, n_read);
+			continue;
 		}
 		data[n] = in[Ctrl->T.col];
 		if (!GMT_is_dnan (data[n])) n++;
@@ -447,8 +449,8 @@ int main (int argc, char **argv)
 				else if (F.hist_type == PSHISTOGRAM_LOG10_FREQ_PCT)
 					yy = d_log101p( 100.0 * F.boxh[ibox] / F.n_counted );
 				else
-					yy = F.boxh[ibox];
-				fprintf (GMT_stdout, format, xx, yy);
+					yy = (double)F.boxh[ibox];
+				fprintf (stdout, format, xx, yy);
 			}
 		}
 		GMT_free ((void *) data);
@@ -520,7 +522,7 @@ int main (int argc, char **argv)
 	GMT_free ((void *) data);
 	GMT_free ((void *) F.boxh);
 
-	Free_Pshistogram_Ctrl (Ctrl);	/* Deallocate control structure */
+	Free_pshistogram_Ctrl (Ctrl);	/* Deallocate control structure */
 
 	GMT_end (argc, argv);
 
@@ -532,7 +534,7 @@ GMT_LONG fill_boxes (struct PSHISTOGRAM_INFO *F, double *data, GMT_LONG n) {
 	double	add_half = 0.0;
 	GMT_LONG	b0, b1, i, ibox, count_sum;
 
-	F->n_boxes = (GMT_LONG)ceil( (F->east - F->west) / F->box_width);
+	F->n_boxes = (GMT_LONG)ceil( ((F->east - F->west) / F->box_width) + 0.5);
 
 	if (F->center_box) {
 		F->n_boxes++;
@@ -611,7 +613,7 @@ GMT_LONG fill_boxes (struct PSHISTOGRAM_INFO *F, double *data, GMT_LONG n) {
 	return (0);
 }
 
-GMT_LONG plot_boxes (struct PSHISTOGRAM_INFO *F, BOOLEAN stairs, BOOLEAN flip_to_y, BOOLEAN draw_outline, struct GMT_PEN *pen, struct GMT_FILL *fill, BOOLEAN cpt)
+GMT_LONG plot_boxes (struct PSHISTOGRAM_INFO *F, GMT_LONG stairs, GMT_LONG flip_to_y, GMT_LONG draw_outline, struct GMT_PEN *pen, struct GMT_FILL *fill, GMT_LONG cpt)
 {
 	GMT_LONG	i, ibox, first = TRUE, index;
 	int rgb[3];
@@ -651,7 +653,7 @@ GMT_LONG plot_boxes (struct PSHISTOGRAM_INFO *F, BOOLEAN stairs, BOOLEAN flip_to
 			else if (F->hist_type == PSHISTOGRAM_LOG10_FREQ_PCT)
 				y[2] = d_log101p( 100.0 * F->boxh[ibox] / F->n_counted );
 			else
-				y[2] = F->boxh[ibox];
+				y[2] = (double)F->boxh[ibox];
 			y[3] = y[2];
 
 			for (i = 0; i < 4; i++) {
@@ -728,10 +730,10 @@ GMT_LONG get_loc_scl (double *data, GMT_LONG n, double *stats)
 	return (0);
 }
 	
-void *New_Pshistogram_Ctrl () {	/* Allocate and initialize a new control structure */
+void *New_pshistogram_Ctrl () {	/* Allocate and initialize a new control structure */
 	struct PSHISTOGRAM_CTRL *C;
 	
-	C = (struct PSHISTOGRAM_CTRL *) GMT_memory (VNULL, (size_t)1, sizeof (struct PSHISTOGRAM_CTRL), "New_Pshistogram_Ctrl");
+	C = (struct PSHISTOGRAM_CTRL *) GMT_memory (VNULL, (size_t)1, sizeof (struct PSHISTOGRAM_CTRL), "New_pshistogram_Ctrl");
 	
 	/* Initialize values whose defaults are not 0/FALSE/NULL */
 	C->E.azimuth = 180.0;
@@ -742,7 +744,7 @@ void *New_Pshistogram_Ctrl () {	/* Allocate and initialize a new control structu
 	return ((void *)C);
 }
 
-void Free_Pshistogram_Ctrl (struct PSHISTOGRAM_CTRL *C) {	/* Deallocate control structure */
+void Free_pshistogram_Ctrl (struct PSHISTOGRAM_CTRL *C) {	/* Deallocate control structure */
 	if (C->C.file) free ((void *)C->C.file);	
 	GMT_free ((void *)C);	
 }
