@@ -1,12 +1,12 @@
 /*--------------------------------------------------------------------
- *	$Id: sample1d.c,v 1.51 2009/07/11 03:16:31 guru Exp $
+ *	$Id: sample1d.c,v 1.65 2011/03/03 21:02:51 guru Exp $
  *
- *	Copyright (c) 1991-2009 by P. Wessel and W. H. F. Smith
- *	See COPYING file for copying and redistribution conditions.
+ *	Copyright (c) 1991-2011 by P. Wessel and W. H. F. Smith
+ *	See LICENSE.TXT file for copying and redistribution conditions.
  *
  *	This program is free software; you can redistribute it and/or modify
  *	it under the terms of the GNU General Public License as published by
- *	the Free Software Foundation; version 2 of the License.
+ *	the Free Software Foundation; version 2 or any later version.
  *
  *	This program is distributed in the hope that it will be useful,
  *	but WITHOUT ANY WARRANTY; without even the implied warranty of
@@ -31,50 +31,65 @@
  
 #include "gmt.h"
 
+#define INT_1D	0	/* Regular 1-D interpolation */
+#define INT_2D	1	/* Spatial 2-D path interpolation */
+
 struct SAMPLE1D_CTRL {
+#ifdef DEBUG
+	struct A {	/* -A[m|p] */
+		int mode;
+	} A;
+#endif
 	struct F {	/* -Fl|a|c */
-		BOOLEAN active;
+		GMT_LONG active;
 		GMT_LONG mode;
 	} F;
-	struct I {	/* -I<inc> */
-		BOOLEAN active;
+	struct I {	/* -I<inc>[e|E|k|K|m|M|n|N|c|C|d|D] */
+		GMT_LONG active;
+		GMT_LONG mode;
 		double inc;
+		char unit;
 	} I;
 	struct T {	/* -T<time_col> */
-		BOOLEAN active;
+		GMT_LONG active;
 		GMT_LONG col;
 	} T;
 	struct N {	/* -N<knotfile> */
-		BOOLEAN active;
+		GMT_LONG active;
 		char *file;
 	} N;
 	struct S {	/* -S<xstart> */
-		BOOLEAN active;
+		GMT_LONG active;
 		double start;
 	} S;
 };
 
 int main (int argc, char **argv)
 {
-	GMT_LONG result, n_col = 0, n_fields, n_expected_fields, n_files = 0, fno, n_args, n_req;
+	GMT_LONG result, n_col = 0, n_read, n_fields, n_expected_fields, n_files = 0, fno, n_args, n_req;
 	GMT_LONG i, j, k, n, m, n_alloc = 0, m_alloc, rows = 1, m_supplied = 0;
 
-	BOOLEAN error = FALSE, *nan_flag = VNULL, nofile = TRUE, done = FALSE;
+	GMT_LONG error = FALSE, *nan_flag = VNULL, nofile = TRUE, done = FALSE;
 
 	double *t_supplied_out = VNULL, *t_out, *ttime, *data, **col = VNULL, **out = VNULL;
 	double tt, low_t, high_t, *in, *dout = VNULL;
-
+#ifdef DEBUG
+	GMT_LONG proj_type = 0;
+	double d_scale;
+	PFD distance_func;
+#endif
 	char line[BUFSIZ], type[3], *not_used = NULL;
 
 	FILE *fp = NULL, *fpt = NULL;
 
+
 	struct SAMPLE1D_CTRL *Ctrl;
 
-	void *New_Sample1d_Ctrl (), Free_Sample1d_Ctrl (struct SAMPLE1D_CTRL *C);
+	void *New_sample1d_Ctrl (), Free_sample1d_Ctrl (struct SAMPLE1D_CTRL *C);
 	
-	argc = GMT_begin (argc, argv);
+	argc = (int)GMT_begin (argc, argv);
 
-	Ctrl = (struct SAMPLE1D_CTRL *)New_Sample1d_Ctrl ();	/* Allocate and initialize a new control structure */
+	Ctrl = (struct SAMPLE1D_CTRL *)New_sample1d_Ctrl ();	/* Allocate and initialize a new control structure */
 	
 	type[0] = 'l';	type[1] = 'a';	type[2] = 'c';
 
@@ -91,7 +106,7 @@ int main (int argc, char **argv)
 				case 'f':
 				case 'm':
 				case '\0':
-					error += GMT_parse_common_options (argv[i], 0, 0, 0, 0);
+					error += (GMT_LONG)GMT_parse_common_options (argv[i], 0, 0, 0, 0);
 					break;
 
 				/* Supplemental parameters */
@@ -118,6 +133,13 @@ int main (int argc, char **argv)
 				case 'I':
 					Ctrl->I.active = TRUE;
 					Ctrl->I.inc = atof (&argv[i][2]);
+#ifdef DEBUG
+					n = strlen (argv[i]) - 1;
+					if (strchr ("ekmnd", argv[i][n])) {
+						Ctrl->I.unit = argv[i][n];
+						Ctrl->I.mode = INT_2D;
+					}
+#endif
 					break;
 				case 'T':
 					Ctrl->T.active = TRUE;
@@ -139,8 +161,18 @@ int main (int argc, char **argv)
 					Ctrl->F.mode = 0;
 					break;
 				case 'A':
-					Ctrl->F.active = TRUE;
-					Ctrl->F.mode = 1;
+#ifdef DEBUG
+					if (argv[i][2] == 'm')
+						Ctrl->A.mode = 1;
+					else if (argv[i][2] == 'p')
+						Ctrl->A.mode = 2;
+					else {	/* Old backwards compatible -A option */
+#endif
+						Ctrl->F.active = TRUE;
+						Ctrl->F.mode = 1;
+#ifdef DEBUG
+					}
+#endif
 					break;
 				case 'C':
 					Ctrl->F.active = TRUE;
@@ -176,6 +208,12 @@ int main (int argc, char **argv)
 		fprintf (stderr, "\t   [Default is -F%c]\n", type[Ctrl->F.mode]);
 		GMT_explain_option ('H');
 		fprintf (stderr, "\t-I <x_inc> sets equidistant grid interval [x1 - x0]\n");
+#ifdef DEBUG
+		fprintf (stderr, "\t   Append e|k|m|n|d to indicate that the first two columns contain\n");
+		fprintf (stderr, "\t   longitude, latitude and you wish to resample this path using great\n");
+		fprintf (stderr, "\t   circle segment with a nominal spacing of <t_inc> in those units.\n");
+		fprintf (stderr, "\t   See -Am|p to only sample along meridians and parallels.\n");
+#endif
 		fprintf (stderr, "\t-N <knotfile> is an ASCII table with the desired time positions in column 0\n");
 		fprintf (stderr, "\t   Overrides the -I and -S settings.  If none of -I, -S, and -N is set\n");
 		fprintf (stderr, "\t   then <tstart> = first input point, <t_inc> = (t[1] - t[0])\n");
@@ -220,6 +258,10 @@ int main (int argc, char **argv)
 		error++;
 	}
 
+#ifdef DEBUG
+	if (Ctrl->I.mode) error += GMT_get_dist_scale (Ctrl->I.unit, &d_scale, &proj_type, &distance_func);
+	if (Ctrl->I.mode) Ctrl->I.inc /= d_scale;			/* Convert increment to spherical degrees */
+#endif
 	if (error) exit (EXIT_FAILURE);
 
 	if (GMT_io.binary[GMT_IN] && gmtdefs.verbose) {
@@ -242,7 +284,7 @@ int main (int argc, char **argv)
 		t_supplied_out = (double *) GMT_memory (VNULL, (size_t)m_alloc, sizeof (double), GMT_program);
 		m = 0;
 		if (GMT_io.io_header[GMT_IN]) for (i = 0; i < GMT_io.n_header_recs; i++) not_used = GMT_fgets (line, BUFSIZ, fpt);
-		n_expected_fields = (GMT_io.ncol[GMT_IN]) ? GMT_io.ncol[GMT_IN] : BUFSIZ;
+		n_expected_fields = (GMT_io.ncol[GMT_IN]) ? GMT_io.ncol[GMT_IN] : GMT_MAX_COLUMNS;
 		n_fields = GMT_input (fpt, &n_expected_fields, &in);
 		while (! (GMT_io.status & GMT_IO_EOF)) {	/* Not yet EOF */
 			while (GMT_io.status & GMT_IO_SEGMENT_HEADER) {
@@ -291,12 +333,12 @@ int main (int argc, char **argv)
 		if (GMT_io.io_header[GMT_IN]) {
 			for (i = 0; i < GMT_io.n_header_recs; i++) {
 				not_used = GMT_fgets (line, BUFSIZ, fp);
-				if (GMT_io.io_header[GMT_OUT]) fprintf (GMT_stdout, "%s", line);
+				if (GMT_io.io_header[GMT_OUT]) GMT_fputs (line, GMT_stdout);
 			}
 		}
 
-		n_expected_fields = (GMT_io.ncol[GMT_IN]) ? GMT_io.ncol[GMT_IN] : BUFSIZ;
-		i = n_col = 0;
+		n_expected_fields = (GMT_io.ncol[GMT_IN]) ? GMT_io.ncol[GMT_IN] : GMT_MAX_COLUMNS;
+		n_read = n_col = 0;
 		n_fields = GMT_input (fp, &n_expected_fields, &in);
 
 		while (! (GMT_io.status & GMT_IO_EOF)) {	/* Not yet EOF */
@@ -307,13 +349,13 @@ int main (int argc, char **argv)
 			}
 			if (GMT_io.status & GMT_IO_EOF) continue;	/* At EOF */
 
-			i++;
 			n = 0;
 
 			while (! (GMT_io.status & (GMT_IO_SEGMENT_HEADER | GMT_IO_EOF))) {	/* Keep going until FALSE or = 2 segment header */
+				n_read++;
 				if (GMT_io.status & GMT_IO_MISMATCH) {
-					fprintf (stderr, "%s: Mismatch between actual (%ld) and expected (%ld) fields near line %ld\n", GMT_program, n_fields, n_expected_fields, i);
-					exit (EXIT_FAILURE);
+					fprintf (stderr, "%s: Mismatch between actual (%ld) and expected (%ld) fields near line %ld\n", GMT_program, n_fields, n_expected_fields, n_read);
+					continue;
 				}
 
 				if (n_col == 0) {	/* Allocate memory first time around */
@@ -325,7 +367,7 @@ int main (int argc, char **argv)
 					dout = (double *) GMT_memory (VNULL, (size_t)n_col, sizeof (double), GMT_program);
 					col = (double **) GMT_memory (VNULL, (size_t)n_col, sizeof (double *), GMT_program);
 					out = (double **) GMT_memory (VNULL, (size_t)n_col, sizeof (double *), GMT_program);
-					nan_flag = (BOOLEAN *) GMT_memory (VNULL, (size_t)n_col, sizeof (BOOLEAN), GMT_program);
+					nan_flag = (GMT_LONG *) GMT_memory (VNULL, (size_t)n_col, sizeof (GMT_LONG), GMT_program);
 					n_alloc = GMT_CHUNK;
 					for (j = 0; j < n_col; j++) col[j] = (double *) GMT_memory (VNULL, (size_t)n_alloc, sizeof (double), GMT_program);
 				}
@@ -348,6 +390,25 @@ int main (int argc, char **argv)
 
 			/* If we didn't get input abscissa, now's the time to generate them */
 
+#ifdef DEBUG
+			if (Ctrl->I.active && Ctrl->I.mode == INT_2D) {	/* Special spatial interpolation */
+				GMT_LONG np;
+				double *lon, *lat, xyout[2];
+				lon = (double *) GMT_memory (VNULL, n, sizeof (double), GMT_program);
+				lat = (double *) GMT_memory (VNULL, n, sizeof (double), GMT_program);
+				memcpy ((void *)lon, (void *)col[GMT_X], n*sizeof(double));
+				memcpy ((void *)lat, (void *)col[GMT_Y], n*sizeof(double));
+				np = GMT_fix_up_path (&lon, &lat, n, Ctrl->I.inc, Ctrl->A.mode);
+				for (i = 0; i < np; i++) {
+					xyout[GMT_X] = lon[i];	xyout[GMT_Y] = lat[i];
+					GMT_output (GMT_stdout, 2, xyout);
+				}
+				rows += n + 1;
+				GMT_free ((void *)lon);
+				GMT_free ((void *)lat);
+				continue;
+			}
+#endif
 			if (Ctrl->N.active) {	/* Get relevant t_out segment */
 				low_t  = MIN (col[Ctrl->T.col][0], col[Ctrl->T.col][n-1]);
 				high_t = MAX (col[Ctrl->T.col][0], col[Ctrl->T.col][n-1]);
@@ -449,17 +510,17 @@ int main (int argc, char **argv)
 	if (nan_flag) GMT_free ((void *)nan_flag);
 	if (Ctrl->N.active) GMT_free ((void *)t_supplied_out);
 	
-	Free_Sample1d_Ctrl (Ctrl);	/* Deallocate control structure */
+	Free_sample1d_Ctrl (Ctrl);	/* Deallocate control structure */
 
 	GMT_end (argc, argv);
 
 	exit (EXIT_SUCCESS);
 }
 
-void *New_Sample1d_Ctrl () {	/* Allocate and initialize a new control structure */
+void *New_sample1d_Ctrl () {	/* Allocate and initialize a new control structure */
 	struct SAMPLE1D_CTRL *C;
 	
-	C = (struct SAMPLE1D_CTRL *) GMT_memory (VNULL, (size_t)1, sizeof (struct SAMPLE1D_CTRL), "New_Sample1d_Ctrl");
+	C = (struct SAMPLE1D_CTRL *) GMT_memory (VNULL, (size_t)1, sizeof (struct SAMPLE1D_CTRL), "New_sample1d_Ctrl");
 	
 	/* Initialize values whose defaults are not 0/FALSE/NULL */
 	C->F.mode = gmtdefs.interpolant;
@@ -467,7 +528,7 @@ void *New_Sample1d_Ctrl () {	/* Allocate and initialize a new control structure
 	return ((void *)C);
 }
 
-void Free_Sample1d_Ctrl (struct SAMPLE1D_CTRL *C) {	/* Deallocate control structure */
+void Free_sample1d_Ctrl (struct SAMPLE1D_CTRL *C) {	/* Deallocate control structure */
 	if (C->N.file) free ((void *)C->N.file);	
 	GMT_free ((void *)C);	
 }
